"""
mvodb package.

Rename and move files using metadata from online databases.

If you read this message, you probably want to learn about the library and not the command-line tool:
please refer to the README.md included in this package to get the link to the official documentation.
"""

__all__ = []
